# GearKits

Gather all the general services API in basic usage. This package is built for what we need in our side projects of open source.

    pip install gearkits

or

    poetry add gearkits

## Services

- telegram
- gitlab
- IPInfo
- AWS(S3, SES)
- Mattermost
